parsedatetime

Package parsedatetime |
[hide private]
[frames] | no frames]

# Package parsedatetime

source code

parsedatetime.py contains the `Calendar` class where the `parse()` method can be found.

parsedatetime_consts.py contains the `Constants` class that builds the various regex values using locale information if available.

Submodules | [hide private]
parsedatetime.parsedatetime: Parse human-readable date/time text. parsedatetime.parsedatetime_consts: parsedatetime constants and helper functions to determine regex values from Locale information if present. parsedatetime.tests: Unit tests for parsedatetime parsedatetime.tests.TestAustralianLocale: Test parsing of simple date and times using the Australian locale parsedatetime.tests.TestComplexDateTimes: Test parsing of complex date and times parsedatetime.tests.TestErrors: Test parsing of units parsedatetime.tests.TestInc: Test Calendar.Inc() routine parsedatetime.tests.TestMultiple: Test parsing of strings with multiple chunks parsedatetime.tests.TestPhrases: Test parsing of strings that are phrases parsedatetime.tests.TestRanges: Test parsing of simple date and times parsedatetime.tests.TestSimpleDateTimes: Test parsing of simple date and times parsedatetime.tests.TestSimpleOffsets: Test parsing of 'simple' offsets parsedatetime.tests.TestUnits: Test parsing of units

Variables | [hide private]
`` | version = `'0.8.3'`
`` | author = `'Mike Taylor and Darshana Chhajed'`
`` | license = `'\nCopyright (c) 2004-2007 Mike Taylor\nCopyright (c...`

Variables Details | [hide private]

    ### version None Value:
        '0.8.3'

    ### author None Value:
        'Mike Taylor and Darshana Chhajed'

    ### license None Value:
        '''
        Copyright (c) 2004-2007 Mike Taylor
        Copyright (c) 2006-2007 Darshana Chhajed
        All rights reserved.

        Licensed under the Apache License, Version 2.0 (the "License");
        you may not use this file except in compliance with the License.
        You may obtain a copy of the License at
        ...